@@ -49,6 +49,14 @@ void Writer::putInt( uint32_t value ) {
 	data[pos++] = (value>>24)&0xFF;
 }
 
+void Writer::putInt64( uint64_t value ) {
+	byteAlign();
+	if( !assure( 8 ) ) return;
+
+	putInt( value >> 32 );
+	putInt( value & 0xffffffff );
+}
+
 void Writer::putFloat( float v ) {
 	byteAlign();
 	if( !assure( 4 ) ) return;
@@ -62,6 +70,13 @@ void Writer::putFloat( float v ) {
 }
 
 void Writer::putDouble( double v ) {
+    union {
+        double d;
+        uint64_t ull;
+    } u;
+    u.d = v;
+    putInt64(u.ull);
+/*
 	byteAlign();
 	if( !assure( 8 ) ) return;
 	// FIXME x86-centric?
@@ -76,6 +91,7 @@ void Writer::putDouble( double v ) {
 	data[pos++] = value[1];
 	data[pos++] = value[2];
 	data[pos++] = value[3];
+*/
 }
 
 void Writer::putFixed( double value, int bytesize, int exp ) {
