@@ -21,6 +21,7 @@ class Writer {
 		void putByte(uint8_t);
 		void putWord(uint16_t);
 		void putInt(uint32_t);
+		void putInt64(uint64_t);
 		void putFloat(float);
 		void putDouble(double);
 		void putFixed( double v, int bytesize, int decimals );
@@ -43,7 +44,7 @@ class Writer {
 		bool assure( int l, int before=-1 ) { 
 			int b = (before==-1?length:before);
 			if( pos+l > b ) {
-				fprintf(stderr,"Write buffer full (%i+%i >= %i)\n", pos, l, length );
+				fprintf(stderr,"Write buffer full (%i+%i >= %i)\n", pos, l, b );
 				err = SWFW_FULL;
 				return false;
 			}
@@ -54,7 +55,7 @@ class Writer {
 		unsigned char *getData() { return data; }
 		int getPosition() { return pos; }
 		int getBits() { return bits; }
-		int getBitPosition() { return (pos*8)-( (8-bits) ); }
+		int getBitPosition() { return (pos*8)+( bits ); }
 		
 	protected:
 		void writeByte( uint8_t value );
