@@ -61,33 +61,14 @@ void Color::dump( int indent, Context *ctx ) {
 	printf("blue: "); 
 	printf("%i\n", blue);
 
-}
-
-void ColorRGBA::dump( int indent, Context *ctx ) {
-	print_indent(indent);
-	
-	
-	printf("ColorRGBA"); // (sz %i)", getSize( ctx ) );
-	
-	printf("\n");
-	indent++;
-	
-	print_indent(indent);
-	printf("red: "); 
-	printf("%i\n", red);
-
-	print_indent(indent);
-	printf("green: "); 
-	printf("%i\n", green);
-
-	print_indent(indent);
-	printf("blue: "); 
-	printf("%i\n", blue);
-
+	if( ctx->alpha ) {
+		
 	print_indent(indent);
 	printf("alpha: "); 
 	printf("%i\n", alpha);
 
+	}
+
 }
 
 void String::dump( int indent, Context *ctx ) {
@@ -344,6 +325,14 @@ void StyleList::dump( int indent, Context *ctx ) {
 		}
 	}
 
+	print_indent(indent);
+	printf("fillBits: "); 
+	printf("%i\n", fillBits);
+
+	print_indent(indent);
+	printf("lineBits: "); 
+	printf("%i\n", lineBits);
+
 }
 
 void ShapeSetup::dump( int indent, Context *ctx ) {
@@ -471,6 +460,33 @@ void Shape::dump( int indent, Context *ctx ) {
 	printf("\n");
 	indent++;
 	
+	print_indent(indent);
+	printf("edges: "); 
+	{
+		printf("[list of ShapeItems]\n");
+		ShapeItem *item;
+		ListItem<ShapeItem>* i;
+		i = edges.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				item->dump(indent+1,ctx);
+			}
+			i = i->next();
+		}
+	}
+
+}
+
+void GlyphShape::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+	
+	printf("GlyphShape"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
 	print_indent(indent);
 	printf("fillBits: "); 
 	printf("%i\n", fillBits);
@@ -1495,6 +1511,82 @@ void DefineFontInfo::dump( int indent, Context *ctx ) {
 
 }
 
+void DefineShape2::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x16);
+	
+	
+	printf("DefineShape2"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	print_indent(indent);
+	printf("data: "); 
+	printf("[Rest]\n");
+	data.dump( indent+1, ctx );
+
+}
+
+void DefineShape3::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x20);
+	
+	
+	printf("DefineShape3"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	print_indent(indent);
+	printf("bounds: "); 
+	printf("[Rectangle]\n");
+	bounds.dump( indent+1, ctx );
+
+	print_indent(indent);
+	printf("styles: "); 
+	printf("[StyleList]\n");
+	styles.dump( indent+1, ctx );
+
+	print_indent(indent);
+	printf("shapes: "); 
+	printf("[Shape]\n");
+	shapes.dump( indent+1, ctx );
+
+}
+
+void DefineMorphShape::dump( int indent, Context *ctx ) {
+	print_indent(indent);
+	
+		printf("[%02X] ", type ); //0x2E);
+	
+	
+	printf("DefineMorphShape"); // (sz %i)", getSize( ctx ) );
+	
+	printf("\n");
+	indent++;
+	
+	print_indent(indent);
+	printf("objectID: "); 
+	printf("%i\n", objectID);
+
+	print_indent(indent);
+	printf("data: "); 
+	printf("[Rest]\n");
+	data.dump( indent+1, ctx );
+
+}
+
 void DefineFontInfo2::dump( int indent, Context *ctx ) {
 	print_indent(indent);
 	
@@ -1954,7 +2046,7 @@ void DefineEditText::dump( int indent, Context *ctx ) {
 		
 	print_indent(indent);
 	printf("color: "); 
-	printf("[ColorRGBA]\n");
+	printf("[Color]\n");
 	color.dump( indent+1, ctx );
 
 	}
