@@ -4,6 +4,9 @@ const char *xslt_library =
 "<xsl:stylesheet	xmlns:xsl=\"http://www.w3.org/1999/XSL/Transform\" \n"
 "				xmlns:swft=\"http://subsignal.org/swfml/swft\"\n"
 "				xmlns:str=\"http://exslt.org/strings\"\n"
+"				xmlns:math=\"http://exslt.org/math\"\n"
+"				xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\"\n"
+"				xmlns:svg=\"http://www.w3.org/2000/svg\"\n"
 "				extension-element-prefixes=\"swft\"\n"
 "				version='1.0'>\n"
 "\n"
@@ -127,10 +130,11 @@ const char *xslt_library =
 "	<xsl:variable name=\"alpha\">\n"
 "		<xsl:choose>\n"
 "			<xsl:when test=\"@alpha\"><xsl:value-of select=\"@alpha\"/></xsl:when>\n"
+"			<xsl:when test=\"string-length(@color) = 9\">0x<xsl:value-of select=\"substring(@color,8)\"/></xsl:when>\n"
 "			<xsl:otherwise>255</xsl:otherwise>\n"
 "		</xsl:choose>\n"
 "	</xsl:variable>\n"
-"	<ColorRGBA red=\"{$red}\" green=\"{$green}\" blue=\"{$blue}\" alpha=\"{$alpha}\"/>\n"
+"	<Color red=\"{$red}\" green=\"{$green}\" blue=\"{$blue}\" alpha=\"{$alpha}\"/>\n"
 "</xsl:template>\n"
 "\n"
 "<!-- background color -->\n"
@@ -422,6 +426,11 @@ const char *xslt_library =
 "				<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
 "			</xsl:apply-templates>\n"
 "		</xsl:when>\n"
+"		<xsl:when test=\"$ext = 'svg'\">\n"
+"			<xsl:apply-templates select=\"document($file)\" mode=\"makesvg\">\n"
+"				<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
+"			</xsl:apply-templates>\n"
+"		</xsl:when>\n"
 "	</xsl:choose>\n"
 "	<xsl:if test=\"ancestor::library\">\n"
 "		<xsl:apply-templates select=\"*|@*\" mode=\"export\">\n"
@@ -563,31 +572,259 @@ const char *xslt_library =
 "\n"
 "<!-- SWF import -->\n"
 "<xsl:template match=\"swf\" mode=\"makeswf\">\n"
-"	<swft:push-map/>\n"
 "	<xsl:param name=\"id\"/>\n"
-"	<xsl:variable name=\"swfID\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable> \n"
-"	\n"
+"	<swft:push-map/>\n"
+"\n"
 "	<xsl:apply-templates select=\"Header/tags/*\" mode=\"sprite-global\"/>\n"
-"		\n"
-"	<DefineSprite objectID=\"{$swfID}\" frames=\"{count(Header/tags/ShowFrame)}\">\n"
+"	\n"
+"	<DefineSprite objectID=\"{$id}\" frames=\"{count(Header/tags/ShowFrame)}\">\n"
 "		<tags>\n"
 "			<xsl:apply-templates select=\"Header/tags/*\" mode=\"sprite-local\"/>\n"
 "		</tags>\n"
 "	</DefineSprite>\n"
+"	\n"
+"	<swft:pop-map/>\n"
+"</xsl:template>\n"
+"\n"
+"<!-- SVG import -->\n"
+"<xsl:template match=\"svg:svg\" mode=\"makesvg\">\n"
+"	<xsl:param name=\"id\"/>\n"
 "	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
 "		<tags>\n"
-"			<PlaceObject2 replace=\"0\" depth=\"1\" objectID=\"{$swfID}\">\n"
+"			<xsl:apply-templates mode=\"svg\"/>\n"
+"			<ShowFrame/>\n"
+"			<End/>\n"
+"		</tags>\n"
+"	</DefineSprite>\n"
+"</xsl:template>\n"
+"\n"
+"<xsl:template match=\"svg:g|svg:path|svg:rect\" mode=\"svg\">\n"
+"	<xsl:variable name=\"id\"><xsl:value-of select=\"swft:map-id(@id)\"/></xsl:variable> \n"
+"	<xsl:variable name=\"xofs\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@inkscape:px\">\n"
+"				<xsl:value-of select=\"@inkscape:px\"/>\n"
+"			</xsl:when>\n"
+"			<xsl:otherwise>0</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable> \n"
+"	<xsl:variable name=\"yofs\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@inkscape:py\">\n"
+"				<xsl:value-of select=\"@inkscape:py\"/>\n"
+"			</xsl:when>\n"
+"			<xsl:otherwise>0</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable> \n"
+"	<xsl:variable name=\"name\" select=\"@id\"/>\n"
+"	<xsl:variable name=\"class\" select=\"@class\"/>\n"
+"\n"
+"	<xsl:apply-templates select=\".\" mode=\"svg-inner\">\n"
+"		<xsl:with-param name=\"id\" select=\"$id\"/>\n"
+"		<xsl:with-param name=\"xofs\" select=\"$xofs\"/>\n"
+"		<xsl:with-param name=\"yofs\" select=\"$yofs\"/>\n"
+"	</xsl:apply-templates>\n"
+"\n"
+"	<PlaceObject2 replace=\"0\" depth=\"{swft:next-depth()}\" objectID=\"{$id}\" name=\"{$name}\">\n"
+"		<transform>\n"
+"			<Transform transX=\"{$xofs*20}\" transY=\"{$yofs*20}\"/>\n"
+"		</transform>\n"
+"	</PlaceObject2>\n"
+"\n"
+"	<Export>\n"
+"		<symbols>\n"
+"		  <Symbol objectID=\"{$id}\" name=\"{$name}\"/>\n"
+"		</symbols>\n"
+"	</Export>\n"
+"	\n"
+"		<!-- debugging: spin everything\n"
+"		<xsl:call-template name=\"register-class\">\n"
+"			<xsl:with-param name=\"class\">org.iterative.Spinner</xsl:with-param>\n"
+"			<xsl:with-param name=\"linkage-id\" select=\"$name\"/>\n"
+"		</xsl:call-template>\n"
+"	-->\n"
+"	<xsl:if test=\"string-length($class) > 0\">\n"
+"		<xsl:call-template name=\"register-class\">\n"
+"			<xsl:with-param name=\"class\" select=\"$class\"/>\n"
+"			<xsl:with-param name=\"linkage-id\" select=\"$name\"/>\n"
+"		</xsl:call-template>\n"
+"	</xsl:if>\n"
+"</xsl:template>\n"
+"\n"
+"<xsl:template match=\"svg:g\" mode=\"svg-inner\">\n"
+"	<xsl:param name=\"id\"/>\n"
+"	<xsl:param name=\"xofs\"/>\n"
+"	<xsl:param name=\"yofs\"/>\n"
+"	<xsl:variable name=\"subid\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable> \n"
+"\n"
+"	<DefineSprite objectID=\"{$subid}\" frames=\"1\">\n"
+"		<tags>\n"
+"			<xsl:apply-templates mode=\"svg\"/>\n"
+"			<ShowFrame/>\n"
+"			<End/>\n"
+"		</tags>\n"
+"	</DefineSprite>\n"
+"	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
+"		<tags>\n"
+"			<PlaceObject2 replace=\"0\" depth=\"{swft:next-depth()}\" objectID=\"{$subid}\">\n"
 "				<transform>\n"
-"					<Transform transX=\"0\" transY=\"0\" />\n"
+"					<xsl:choose>\n"
+"						<xsl:when test=\"@transform\">\n"
+"							<xsl:copy-of select=\"swft:transform(@transform,-$xofs,-$yofs)\"/>\n"
+"						</xsl:when>\n"
+"						<xsl:otherwise>\n"
+"							<Transform transX=\"{$xofs*-20}\" transY=\"{$yofs*-20}\"/>\n"
+"						</xsl:otherwise>\n"
+"					</xsl:choose>\n"
 "				</transform>\n"
 "			</PlaceObject2>\n"
 "			<ShowFrame/>\n"
 "			<End/>\n"
 "		</tags>\n"
 "	</DefineSprite>\n"
-"	<swft:pop-map/>\n"
 "</xsl:template>\n"
 "\n"
+"<xsl:template match=\"svg:path\" mode=\"svg-inner\">\n"
+"	<xsl:param name=\"id\"/>\n"
+"	<xsl:param name=\"xofs\"/>\n"
+"	<xsl:param name=\"yofs\"/>\n"
+"	<xsl:variable name=\"shapeid\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable> \n"
+"\n"
+"	<DefineShape3 objectID=\"{$shapeid}\">\n"
+"		<bounds>\n"
+"			<!-- bounds needs to respect offset? -->\n"
+"				<xsl:copy-of select=\"swft:bounds(@d,-$xofs,-$yofs)\"/>\n"
+"		</bounds>\n"
+"		<styles>\n"
+"			<StyleList>\n"
+"				<xsl:copy-of select=\"swft:css(@style)/tmp/*\"/>\n"
+"			</StyleList>\n"
+"		</styles>\n"
+"		<shapes>\n"
+"			<Shape>\n"
+"				<xsl:apply-templates mode=\"shape\" select=\"swft:path(@d,-$xofs,-$yofs)/tmp/Shape/*\"/>\n"
+"			</Shape>\n"
+"		</shapes>\n"
+"	</DefineShape3>\n"
+"	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
+"		<tags>\n"
+"			<PlaceObject2 replace=\"0\" depth=\"{swft:next-depth()}\" objectID=\"{$shapeid}\">\n"
+"				<transform>\n"
+"			<xsl:choose>\n"
+"				<xsl:when test=\"@transform\">\n"
+"					<xsl:copy-of select=\"swft:transform(@transform)\"/>\n"
+"				</xsl:when>\n"
+"				<xsl:otherwise>\n"
+"					<Transform transX=\"0\" transY=\"0\"/>\n"
+"				</xsl:otherwise>\n"
+"			</xsl:choose>\n"
+"				</transform>\n"
+"			</PlaceObject2>\n"
+"			<ShowFrame/>\n"
+"			<End/>\n"
+"		</tags>\n"
+"	</DefineSprite>\n"
+"</xsl:template>\n"
+"\n"
+"<xsl:template match=\"svg:rect\" mode=\"svg-inner\">\n"
+"	<xsl:param name=\"id\"/>\n"
+"	<xsl:param name=\"xofs\"/>\n"
+"	<xsl:param name=\"yofs\"/>\n"
+"	<xsl:variable name=\"shapeid\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable> \n"
+"\n"
+"	<DefineShape3 objectID=\"{$shapeid}\">\n"
+"		<bounds>\n"
+"			<Rectangle left=\"0\" right=\"{@width*20}\" top=\"0\" bottom=\"{@height*20}\"/>\n"
+"		</bounds>\n"
+"		<styles>\n"
+"			<StyleList>\n"
+"				<xsl:copy-of select=\"swft:css(@style)/tmp/*\"/>\n"
+"			</StyleList>\n"
+"		</styles>\n"
+"		<shapes>\n"
+"			<Shape>\n"
+"				<edges>\n"
+"					<ShapeSetup x=\"{(@width)*20}\" y=\"{(@height)*20}\" fillStyle0=\"1\" lineStyle=\"1\"/>\n"
+"					<LineTo x=\"-{(@width)*20}\" y=\"0\"/>\n"
+"					<LineTo x=\"0\" y=\"-{(@height)*20}\"/>\n"
+"					<LineTo x=\"{(@width)*20}\" y=\"0\"/>\n"
+"					<LineTo x=\"0\" y=\"{(@height)*20}\"/>\n"
+"					<ShapeSetup/>\n"
+"				</edges>\n"
+"			</Shape>\n"
+"		</shapes>\n"
+"	</DefineShape3>\n"
+"	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
+"		<tags>\n"
+"			<PlaceObject2 replace=\"0\" depth=\"{swft:next-depth()}\" objectID=\"{$shapeid}\">\n"
+"				<transform>\n"
+"					<Transform transX=\"{(@x - $xofs)*20}\" transY=\"{(@y - $yofs)*20}\"/>\n"
+"				</transform>\n"
+"			</PlaceObject2>\n"
+"			<ShowFrame/>\n"
+"			<End/>\n"
+"		</tags>\n"
+"	</DefineSprite>\n"
+"</xsl:template>\n"
+"\n"
+"<xsl:template match=\"svg:flowRoot\" mode=\"svg-inner\">\n"
+"	<xsl:param name=\"id\"/>\n"
+"	<xsl:param name=\"xofs\"/>\n"
+"	<xsl:param name=\"yofs\"/>\n"
+"	<xsl:variable name=\"subid\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable> \n"
+"\n"
+"	<DefineEditText objectID=\"{$subid}\" wordWrap=\"1\" multiLine=\"1\" password=\"0\" \n"
+"		readOnly=\"1\" autoSize=\"0\" hasLayout=\"1\"\n"
+"		notSelectable=\"1\" hasBorder=\"0\" isHTML=\"0\" useOutlines=\"1\" \n"
+"		fontRef=\"{swft:map-id(vera)}\" fontHeight=\"12\"\n"
+"		align=\"0\" leftMargin=\"0\" rightMargin=\"0\" indent=\"0\" leading=\"40\" \n"
+"		variableName=\"{@id}\">\n"
+"		<xsl:attribute name=\"initialText\">\n"
+"			foo?\n"
+"		</xsl:attribute>\n"
+"		<size>\n"
+"			<Rectangle left=\"{svg:flowRegion/@x}\" \n"
+"						right=\"{svg:flowRegion/@x + svg:flowRegion/@width}\" \n"
+"						top=\"{svg:flowRegion/@y}\" \n"
+"						bottom=\"{$svg:flowRegion/@y + $svg:flowRegion/@height}\"/>\n"
+"		</size>\n"
+"		<color>\n"
+"			<Color red=\"255\" green=\"255\" blue=\"255\"/>\n"
+"		</color>\n"
+"	</DefineEditText>\n"
+"	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
+"		<tags>\n"
+"			<PlaceObject2 replace=\"0\" depth=\"{swft:next-depth()}\" objectID=\"{$subid}\">\n"
+"				<transform>\n"
+"					<xsl:choose>\n"
+"						<xsl:when test=\"@transform\">\n"
+"							<xsl:copy-of select=\"swft:transform(@transform,-$xofs,-$yofs)\"/>\n"
+"						</xsl:when>\n"
+"						<xsl:otherwise>\n"
+"							<Transform transX=\"{$xofs*-20}\" transY=\"{$yofs*-20}\"/>\n"
+"						</xsl:otherwise>\n"
+"					</xsl:choose>\n"
+"				</transform>\n"
+"			</PlaceObject2>\n"
+"			<ShowFrame/>\n"
+"			<End/>\n"
+"		</tags>\n"
+"	</DefineSprite>\n"
+"</xsl:template>\n"
+"\n"
+"<xsl:template match=\"*|@*|text()\" mode=\"svg\" priority=\"-1\"/>\n"
+"\n"
+"\n"
+"<xsl:template match=\"ShapeSetup\" mode=\"shape\">\n"
+"	<ShapeSetup fillStyle0=\"1\" fillStyle1=\"2\" lineStyle=\"1\">\n"
+"		<xsl:apply-templates select=\"*|@*\" mode=\"shape\"/>\n"
+"	</ShapeSetup>\n"
+"</xsl:template>\n"
+"<xsl:template match=\"*|@*|text()\" mode=\"shape\" priority=\"-1\">\n"
+"	<xsl:copy-of select=\".\"/>\n"
+"</xsl:template>\n"
+"\n"
+"\n"
 "<!-- shared library import -->\n"
 "<xsl:template match=\"import\">\n"
 "	<Import url=\"{@url}\">\n"
@@ -685,13 +922,14 @@ const char *xslt_library =
 "	</DoInitAction>\n"
 "</xsl:template>\n"
 "\n"
+"<!-- works only if the id is exported! -->\n"
 "<xsl:template name=\"register-class\">\n"
 "	<xsl:param name=\"class\"/>\n"
 "	<xsl:param name=\"linkage-id\"/>\n"
 "	<xsl:variable name=\"packages\" select=\"str:tokenize($class,'.')\"/>\n"
 "	<xsl:variable name=\"strofs\">3</xsl:variable>\n"
 "	<xsl:variable name=\"id\" select=\"swft:next-id()\"/>\n"
-"	\n"
+"\n"
 "	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
 "		<tags>\n"
 "		  <End/>\n"
